<?php
	if ( ! defined( 'ABSPATH' ) ) {
		exit; // Exit if accessed directly.
	}

	class ZLEADSCRM_PIPELINE_Core_Admin {
		public function __construct() {
			add_action( 'plugins_loaded', array( $this, 'init_hooks' ), 70 );
		}


		public function init_hooks() {
			if ( ! class_exists( 'ZLEADSCRM_BASIC_Core' ) ) {
				add_action( 'admin_notices', function () {
					?>
                    <div class="notice notice-error is-dismissible">
                        <p>To be able to use Leads Pipeline Add-on, you need to install the Leads Basic Plugin
                            first!</p>
                    </div>
					<?php

				} );

				return;
			}


			add_action( 'admin_init', array( $this, 'admin_init' ) );

			add_action( 'admin_menu', array( $this, 'admin_menu' ), 40 ); // Add Menu Item

			/* Form Post */
			add_action( 'admin_post_zleadscrm_edit_settings', array( $this, 'edit_settings' ), 40 );
			add_action( 'admin_post_zleadscrm_add_new_lead_from_shortcode', array(
				$this,
				'add_new_lead_from_shortcode'
			) );
			add_action( 'admin_post_zleadscrm_add_new_pipeline', array( $this, 'add_new_pipeline' ) );
			add_action( 'admin_post_zleadscrm_edit_pipeline', array( $this, 'edit_pipeline' ) );

			/*Ajax Post*/
			add_action( 'wp_ajax_nopriv_zleadscrm_add_new_shortcode', array(
				$this,
				'add_new_lead_from_shortcode'
			) );
			add_action( 'wp_ajax_zleadscrm_add_new_shortcode', array(
				$this,
				'add_new_lead_from_shortcode'
			) );
		}

		public function admin_init() {
		}

		public function add_new_pipeline() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_add_new_pipeline' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_pipelines&add_new=1' );
				exit();
			}

			$title = '';

			if ( isset( $_POST['zleadscrm_pipeline_form_title'] ) ) {
				$title = sanitize_text_field( $_POST['zleadscrm_pipeline_form_title'] );
			}

			$post_id = wp_insert_post( array(
				'post_type'   => 'zleadscrm_pipeline',
				'post_status' => 'publish',
				'post_title'  => $title
			) );

			update_post_meta( $post_id, 'pipeline_shortcode_id', $post_id );

			if ( isset( $_POST['zleadscrm_pipeline_form_fields'] ) ) {

				update_post_meta( $post_id, 'pipeline_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_email_address', 'yes' );

				$zleadscrm_pipeline_form_fields = zleadscrm_sanitize_array( $_POST['zleadscrm_pipeline_form_fields'] );

				if ( in_array( 'first_name', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_first_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_first_name', 'no' );
				}

				if ( in_array( 'last_name', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_last_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_last_name', 'no' );
				}

				if ( in_array( 'title', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_title', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_title', 'no' );
				}

				if ( in_array( 'phone', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_phone', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_phone', 'no' );
				}

				if ( in_array( 'website', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_website', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_website', 'no' );
				}

				if ( in_array( 'short_description', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_short_description', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_short_description', 'no' );
				}

				if ( in_array( 'billing_details', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_billing_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_billing_details', 'no' );
				}

				if ( in_array( 'shipping_details', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_shipping_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_shipping_details', 'no' );
				}

				if ( in_array( 'brands', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_brands', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_brands', 'no' );
				}
			} else {
				update_post_meta( $post_id, 'pipeline_first_name', 'no' );
				update_post_meta( $post_id, 'pipeline_last_name', 'no' );
				update_post_meta( $post_id, 'pipeline_title', 'no' );
				update_post_meta( $post_id, 'pipeline_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_email_address', 'yes' );
				update_post_meta( $post_id, 'pipeline_website', 'no' );
				update_post_meta( $post_id, 'pipeline_phone', 'no' );
				update_post_meta( $post_id, 'pipeline_short_description', 'no' );
				update_post_meta( $post_id, 'pipeline_billing_details', 'no' );
				update_post_meta( $post_id, 'pipeline_shipping_details', 'no' );
				update_post_meta( $post_id, 'pipeline_brands', 'no' );
			}

			if ( isset( $_POST['zleadscrm_pipeline_form_required_fields'] ) ) {
				update_post_meta( $post_id, 'pipeline_required_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_email_address', 'yes' );

				$zleadscrm_pipeline_form_required_fields = zleadscrm_sanitize_array( $_POST['zleadscrm_pipeline_form_required_fields'] );


				if ( in_array( 'first_name', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_first_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_first_name', 'no' );
				}

				if ( in_array( 'last_name', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_last_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_last_name', 'no' );
				}

				if ( in_array( 'title', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_title', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_title', 'no' );
				}

				if ( in_array( 'phone', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_phone', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_phone', 'no' );
				}

				if ( in_array( 'website', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_website', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_website', 'no' );
				}

				if ( in_array( 'short_description', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_short_description', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_short_description', 'no' );
				}

				if ( in_array( 'billing_details', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_billing_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_billing_details', 'no' );
				}

				if ( in_array( 'shipping_details', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_shipping_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_shipping_details', 'no' );
				}

				if ( in_array( 'brands', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_brands', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_brands', 'no' );
				}
			} else {
				update_post_meta( $post_id, 'pipeline_required_first_name', 'no' );
				update_post_meta( $post_id, 'pipeline_required_last_name', 'no' );
				update_post_meta( $post_id, 'pipeline_required_title', 'no' );
				update_post_meta( $post_id, 'pipeline_required_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_email_address', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_website', 'no' );
				update_post_meta( $post_id, 'pipeline_required_phone', 'no' );
				update_post_meta( $post_id, 'pipeline_required_short_description', 'no' );
				update_post_meta( $post_id, 'pipeline_required_billing_details', 'no' );
				update_post_meta( $post_id, 'pipeline_required_shipping_details', 'no' );
				update_post_meta( $post_id, 'pipeline_required_brands', 'no' );
			}


			if ( isset ( $_POST['zleadscrm_pipeline_lead_status'] ) ) {
				update_post_meta( $post_id, 'pipeline_lead_status', sanitize_text_field( $_POST['zleadscrm_pipeline_lead_status'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_lead_source'] ) ) {
				update_post_meta( $post_id, 'pipeline_lead_source', sanitize_text_field( $_POST['zleadscrm_pipeline_lead_source'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_customer_status'] ) ) {
				update_post_meta( $post_id, 'pipeline_customer_status', sanitize_text_field( $_POST['zleadscrm_pipeline_customer_status'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_account_manager'] ) ) {
				update_post_meta( $post_id, 'pipeline_account_manager', sanitize_text_field( $_POST['zleadscrm_pipeline_account_manager'] ) );
			}

			if ( isset( $_POST['zleadscrm_pipeline_submit_button_text'] ) && ( $_POST['zleadscrm_pipeline_submit_button_text'] != '' ) ) {
				update_post_meta( $post_id, 'pipeline_form_submit_button_text', sanitize_text_field( $_POST['zleadscrm_pipeline_submit_button_text'] ) );
			} else {
				update_post_meta( $post_id, 'pipeline_form_submit_button_text', 'Submit' );
			}

			if ( isset( $_POST['zleadscrm_pipeline_form_redirect_url'] ) && ( $_POST['zleadscrm_pipeline_form_redirect_url'] != '' ) ) {
				update_post_meta( $post_id, 'pipeline_form_redirect_url', sanitize_text_field( $_POST['zleadscrm_pipeline_form_redirect_url'] ) );
			} else {
				update_post_meta( $post_id, 'pipeline_form_redirect_url', home_url() );
			}

			wp_redirect( 'admin.php?page=zleadscrm_pipelines' );
			exit();
		}

		public function edit_pipeline() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_edit_pipeline' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_pipelines' );
				exit();
			}

			$post_id = $_POST['pipeline_id'];

			$title = '';

			if ( isset( $_POST['zleadscrm_pipeline_form_title'] ) ) {
				$title = sanitize_text_field( $_POST['zleadscrm_pipeline_form_title'] );
			}

			wp_update_post( array(
				'ID'         => $post_id,
				'post_title' => $title
			) );

			update_post_meta( $post_id, 'pipeline_shortcode_id', $post_id );

			if ( isset( $_POST['zleadscrm_pipeline_form_fields'] ) ) {

				update_post_meta( $post_id, 'pipeline_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_email_address', 'yes' );

				$zleadscrm_pipeline_form_fields = zleadscrm_sanitize_array( $_POST['zleadscrm_pipeline_form_fields'] );

				if ( in_array( 'first_name', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_first_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_first_name', 'no' );
				}

				if ( in_array( 'last_name', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_last_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_last_name', 'no' );
				}

				if ( in_array( 'title', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_title', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_title', 'no' );
				}

				if ( in_array( 'phone', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_phone', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_phone', 'no' );
				}

				if ( in_array( 'website', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_website', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_website', 'no' );
				}

				if ( in_array( 'short_description', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_short_description', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_short_description', 'no' );
				}

				if ( in_array( 'billing_details', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_billing_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_billing_details', 'no' );
				}

				if ( in_array( 'shipping_details', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_shipping_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_shipping_details', 'no' );
				}

				if ( in_array( 'brands', $zleadscrm_pipeline_form_fields ) ) {
					update_post_meta( $post_id, 'pipeline_brands', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_brands', 'no' );
				}

			} else {
				update_post_meta( $post_id, 'pipeline_first_name', 'no' );
				update_post_meta( $post_id, 'pipeline_last_name', 'no' );
				update_post_meta( $post_id, 'pipeline_title', 'no' );
				update_post_meta( $post_id, 'pipeline_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_email_address', 'yes' );
				update_post_meta( $post_id, 'pipeline_website', 'no' );
				update_post_meta( $post_id, 'pipeline_phone', 'no' );
				update_post_meta( $post_id, 'pipeline_short_description', 'no' );
				update_post_meta( $post_id, 'pipeline_billing_details', 'no' );
				update_post_meta( $post_id, 'pipeline_shipping_details', 'no' );
				update_post_meta( $post_id, 'pipeline_brands', 'no' );
			}

			if ( isset( $_POST['zleadscrm_pipeline_form_required_fields'] ) ) {

				$zleadscrm_pipeline_form_required_fields = zleadscrm_sanitize_array( $_POST['zleadscrm_pipeline_form_required_fields'] );

				update_post_meta( $post_id, 'pipeline_required_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_email_address', 'yes' );

				if ( in_array( 'first_name', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_first_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_first_name', 'no' );
				}

				if ( in_array( 'last_name', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_last_name', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_last_name', 'no' );
				}

				if ( in_array( 'title', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_title', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_title', 'no' );
				}

				if ( in_array( 'phone', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_phone', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_phone', 'no' );
				}

				if ( in_array( 'website', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_website', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_website', 'no' );
				}

				if ( in_array( 'short_description', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_short_description', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_short_description', 'no' );
				}

				if ( in_array( 'billing_details', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_billing_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_billing_details', 'no' );
				}

				if ( in_array( 'shipping_details', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_shipping_details', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_shipping_details', 'no' );
				}

				if ( in_array( 'brands', $zleadscrm_pipeline_form_required_fields ) ) {
					update_post_meta( $post_id, 'pipeline_required_brands', 'yes' );
				} else {
					update_post_meta( $post_id, 'pipeline_required_brands', 'no' );
				}
			} else {
				update_post_meta( $post_id, 'pipeline_required_first_name', 'no' );
				update_post_meta( $post_id, 'pipeline_required_last_name', 'no' );
				update_post_meta( $post_id, 'pipeline_required_title', 'no' );
				update_post_meta( $post_id, 'pipeline_required_business_name', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_email_address', 'yes' );
				update_post_meta( $post_id, 'pipeline_required_website', 'no' );
				update_post_meta( $post_id, 'pipeline_required_phone', 'no' );
				update_post_meta( $post_id, 'pipeline_required_short_description', 'no' );
				update_post_meta( $post_id, 'pipeline_required_billing_details', 'no' );
				update_post_meta( $post_id, 'pipeline_required_shipping_details', 'no' );
				update_post_meta( $post_id, 'pipeline_required_brands', 'no' );
			}


			if ( isset ( $_POST['zleadscrm_pipeline_lead_status'] ) ) {
				update_post_meta( $post_id, 'pipeline_lead_status', sanitize_text_field( $_POST['zleadscrm_pipeline_lead_status'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_lead_source'] ) ) {
				update_post_meta( $post_id, 'pipeline_lead_source', sanitize_text_field( $_POST['zleadscrm_pipeline_lead_source'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_customer_status'] ) ) {
				update_post_meta( $post_id, 'pipeline_customer_status', sanitize_text_field( $_POST['zleadscrm_pipeline_customer_status'] ) );
			}

			if ( isset ( $_POST['zleadscrm_pipeline_account_manager'] ) ) {
				update_post_meta( $post_id, 'pipeline_account_manager', sanitize_text_field( $_POST['zleadscrm_pipeline_account_manager'] ) );
			}

			if ( isset( $_POST['zleadscrm_pipeline_submit_button_text'] ) && ( $_POST['zleadscrm_pipeline_submit_button_text'] != '' ) ) {
				update_post_meta( $post_id, 'pipeline_form_submit_button_text', sanitize_text_field( $_POST['zleadscrm_pipeline_submit_button_text'] ) );
			} else {
				update_post_meta( $post_id, 'pipeline_form_submit_button_text', 'Submit' );
			}

			if ( isset( $_POST['zleadscrm_pipeline_form_redirect_url'] ) && ( $_POST['zleadscrm_pipeline_form_redirect_url'] != '' ) ) {
				update_post_meta( $post_id, 'pipeline_form_redirect_url', sanitize_text_field( $_POST['zleadscrm_pipeline_form_redirect_url'] ) );
			} else {
				update_post_meta( $post_id, 'pipeline_form_redirect_url', home_url() );
			}

			wp_redirect( 'admin.php?page=zleadscrm_pipelines&upd=1&edit_pipeline=' . $post_id );
			exit();
		}

		public function add_new_lead_from_shortcode() {


			if ( ! isset( $_POST['_wp_nonce'] ) || ! wp_verify_nonce( $_POST['_wp_nonce'], 'zleadscrm_add_new_lead_from_shortcode' ) ) {
				print( home_url() );
				exit();
			}

			if ( isset( $_POST['zleadscrm_lead_business_name'] ) && $_POST['zleadscrm_lead_business_name'] != '' ) {
				$username = preg_replace( '/[^A-Za-z0-9\-]/', '', sanitize_text_field( $_POST['zleadscrm_lead_business_name'] ) );
				$username = strtolower( $username );
				$username = str_replace( ' ', '', $username );

				$user_id                    = wp_create_user( $username, wp_generate_password(), sanitize_text_field( $_POST['zleadscrm_lead_email_address'] ) );
				$send_new_user_notification = get_option( 'zleadscrm_new_user_email_notification', 'off' );
				if ( $send_new_user_notification == 'on' ) {
					wp_new_user_notification( $user_id, null, 'user' );
				}
			} else {
				print( home_url() );
				exit();
			}

			$shortcode_id = sanitize_text_field( $_POST['shortcode_id'] );

			$redirect_url = get_post_meta( $shortcode_id, 'pipeline_form_redirect_url', true );

			if ( isset( $_POST['zleadscrm_lead_first_name'] ) && $_POST['zleadscrm_lead_first_name'] != '' ) {
				update_user_meta( $user_id, 'first_name', sanitize_text_field( $_POST['zleadscrm_lead_first_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_lead_last_name'] ) && $_POST['zleadscrm_lead_last_name'] != '' ) {
				update_user_meta( $user_id, 'last_name', sanitize_text_field( $_POST['zleadscrm_lead_last_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_lead_title'] ) && $_POST['zleadscrm_lead_title'] != '' ) {
				update_user_meta( $user_id, 'zleadscrm_title', sanitize_text_field( $_POST['zleadscrm_lead_title'] ) );
			}

			if ( isset( $_POST['zleadscrm_lead_business_name'] ) && $_POST['zleadscrm_lead_business_name'] != '' ) {
				update_user_meta( $user_id, 'zleadscrm_business_name', sanitize_text_field( $_POST['zleadscrm_lead_business_name'] ) );
			}

			$shortcode_lead_source = get_post_meta( $shortcode_id, 'pipeline_lead_source', true );
			if ( $shortcode_lead_source != '' && $shortcode_lead_source != 'select' ) {
				update_user_meta( $user_id, 'zleadscrm_lead_source', $shortcode_lead_source );
			}

			$shortcode_account_manager = get_post_meta( $shortcode_id, 'pipeline_account_manager', true );
			if ( $shortcode_account_manager != '' && $shortcode_account_manager != '0' ) {
				update_user_meta( $user_id, 'zleadscrm_account_manager', (int) $shortcode_account_manager );
				zacctmgr_insert_account_manager_assignment( array(
					'timestamp'   => current_time( 'mysql' ),
					'manager_id'  => $shortcode_account_manager,
					'customer_id' => $user_id
				) );
				update_user_meta( $user_id, 'zacctmgr_assigned', $shortcode_account_manager );

				$send_account_manager_notification_email = get_option( 'zleadscrm_acm_assignment_notification_email', 'off' );

				if ( $send_account_manager_notification_email == 'on' ) {
					$account_manager = get_user_by( 'id', $shortcode_account_manager );
					$user            = get_user_by( 'id', $user_id );
					$edit_url        = admin_url( 'admin.php' ) . '?page=zleadscrm_bookmarks&tab=leads&edit_lead=' . $user_id;
					$subject         = 'A new lead has been assigned to you!';
					$body            = 'A new lead ' . esc_html( $user->last_name ) . ', ' . esc_html( $user->first_name ) . ' has been assigned to you, <a href="' . esc_url( $edit_url ) . '">view lead</a> on ' . get_bloginfo( 'name' );

					add_filter( 'wp_mail_content_type', array( $this, 'set_html_content_type' ) );
					wp_mail( $account_manager->user_email, $subject, $body );
					remove_filter( 'wp_mail_content_type', array(
						$this,
						'set_html_content_type'
					) );
				}

				$show_account_manager_banner = get_option( 'zleadscrm_show_acm_banner', 'off' );
				if ( $show_account_manager_banner == 'on' ) {
					$show_account_manager_banner = get_option( 'zleadscrm_show_acm_banner', 'off' );
					if ( $show_account_manager_banner == 'on' ) {
						update_user_meta( $user_id, 'zleadscrm_acm_notified', 'no' );
						update_user_meta( $user_id, 'zleadscrm_acm_assign_date', current_time( 'mysql' ) );
					}

				}
			}

			if ( isset( $_POST['zleadscrm_lead_phone'] ) && $_POST['zleadscrm_lead_phone'] != '' ) {
				update_user_meta( $user_id, 'zleadscrm_phone', sanitize_text_field( $_POST['zleadscrm_lead_phone'] ) );
			}

			if ( isset( $_POST['zleadscrm_lead_website'] ) && $_POST['zleadscrm_lead_website'] != '' ) {
				wp_update_user( array(
					'ID'       => $user_id,
					'user_url' => sanitize_text_field( $_POST['zleadscrm_lead_website'] )
				) );
			}

			if ( isset( $_POST['zleadscrm_lead_email_address'] ) && $_POST['zleadscrm_lead_email_address'] != '' ) {
				wp_update_user( array(
					'ID'         => $user_id,
					'user_email' => sanitize_email( $_POST['zleadscrm_lead_email_address'] )
				) );
			}

			$shortcode_lead_status = get_post_meta( $shortcode_id, 'pipeline_lead_status', true );
			if ( $shortcode_lead_status != '' && $shortcode_lead_status != 'select' ) {
				update_user_meta( $user_id, 'zleadscrm_lead_status', $shortcode_lead_status );
			}

			$shortcode_customer_status = get_post_meta( $shortcode_id, 'pipeline_customer_status', true );
			if ( $shortcode_customer_status != '' && $shortcode_customer_status != 'select' ) {
				update_user_meta( $user_id, 'zleadscrm_lead_customer_status', $shortcode_customer_status );
			}

			if ( isset( $_POST['zleadscrm_lead_brands'] ) && $_POST['zleadscrm_lead_brands'] != '' ) {
				update_user_meta( $user_id, 'zleadscrm_brands', zleadscrm_sanitize_array( $_POST['zleadscrm_lead_brands'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_first_name'] ) && $_POST['zleadscrm_billing_first_name'] != '' ) {
				update_user_meta( $user_id, 'billing_first_name', sanitize_text_field( $_POST['zleadscrm_billing_first_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_last_name'] ) && $_POST['zleadscrm_billing_last_name'] != '' ) {
				update_user_meta( $user_id, 'billing_last_name', sanitize_text_field( $_POST['zleadscrm_billing_last_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_company'] ) && $_POST['zleadscrm_billing_company'] != '' ) {
				update_user_meta( $user_id, 'billing_company', sanitize_text_field( $_POST['zleadscrm_billing_company'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_address_1'] ) && $_POST['zleadscrm_billing_address_1'] != '' ) {
				update_user_meta( $user_id, 'billing_address_1', sanitize_text_field( $_POST['zleadscrm_billing_address_1'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_address_2'] ) && $_POST['zleadscrm_billing_address_2'] != '' ) {
				update_user_meta( $user_id, 'billing_address_2', sanitize_text_field( $_POST['zleadscrm_billing_address_2'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_city'] ) && $_POST['zleadscrm_billing_city'] != '' ) {
				update_user_meta( $user_id, 'billing_city', sanitize_text_field( $_POST['zleadscrm_billing_city'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_postcode'] ) && $_POST['zleadscrm_billing_postcode'] != '' ) {
				update_user_meta( $user_id, 'billing_postcode', sanitize_text_field( $_POST['zleadscrm_billing_postcode'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_country'] ) && $_POST['zleadscrm_billing_country'] != 'select' ) {
				update_user_meta( $user_id, 'billing_country', sanitize_text_field( $_POST['zleadscrm_billing_country'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_state'] ) && $_POST['zleadscrm_billing_state'] != '' ) {
				update_user_meta( $user_id, 'billing_state', sanitize_text_field( $_POST['zleadscrm_billing_state'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_email'] ) && $_POST['zleadscrm_billing_email'] != '' ) {
				update_user_meta( $user_id, 'billing_email', sanitize_text_field( $_POST['zleadscrm_billing_email'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_phone'] ) && $_POST['zleadscrm_billing_phone'] != '' ) {
				update_user_meta( $user_id, 'billing_phone', sanitize_text_field( $_POST['zleadscrm_billing_phone'] ) );
			}

			if ( isset( $_POST['zleadscrm_billing_payment_method'] ) && $_POST['zleadscrm_billing_payment_method'] != '' ) {
				update_user_meta( $user_id, 'zleadscrm_billing_payment_method', sanitize_text_field( $_POST['zleadscrm_billing_payment_method'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_first_name'] ) && $_POST['zleadscrm_shipping_first_name'] != '' ) {
				update_user_meta( $user_id, 'shipping_first_name', sanitize_text_field( $_POST['zleadscrm_shipping_first_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_last_name'] ) && $_POST['zleadscrm_shipping_last_name'] != '' ) {
				update_user_meta( $user_id, 'shipping_last_name', sanitize_text_field( $_POST['zleadscrm_shipping_last_name'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_company'] ) && $_POST['zleadscrm_shipping_company'] != '' ) {
				update_user_meta( $user_id, 'shipping_company', sanitize_text_field( $_POST['zleadscrm_shipping_company'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_address_1'] ) && $_POST['zleadscrm_shipping_address_1'] != '' ) {
				update_user_meta( $user_id, 'shipping_address_1', sanitize_text_field( $_POST['zleadscrm_shipping_address_1'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_address_2'] ) && $_POST['zleadscrm_shipping_address_2'] != '' ) {
				update_user_meta( $user_id, 'shipping_address_2', sanitize_text_field( $_POST['zleadscrm_shipping_address_2'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_city'] ) && $_POST['zleadscrm_shipping_city'] != '' ) {
				update_user_meta( $user_id, 'shipping_city', sanitize_text_field( $_POST['zleadscrm_shipping_city'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_postcode'] ) && $_POST['zleadscrm_shipping_postcode'] != '' ) {
				update_user_meta( $user_id, 'shipping_postcode', sanitize_text_field( $_POST['zleadscrm_shipping_postcode'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_country'] ) && $_POST['zleadscrm_shipping_country'] != 'select' ) {
				update_user_meta( $user_id, 'shipping_country', sanitize_text_field( $_POST['zleadscrm_shipping_country'] ) );
			}

			if ( isset( $_POST['zleadscrm_shipping_state'] ) && $_POST['zleadscrm_shipping_state'] != '' ) {
				update_user_meta( $user_id, 'shipping_state', sanitize_text_field( $_POST['zleadscrm_shipping_state'] ) );
			}

			if ( isset( $_POST['zleadscrm_short_description'] ) && $_POST['zleadscrm_short_description'] != '' ) {
				update_user_meta( $user_id, 'description', sanitize_textarea_field( $_POST['zleadscrm_short_description'] ) );
			}

			update_user_meta( $user_id, 'zleadscrm_last_edit', current_time( 'timestamp' ) );

			update_user_meta( $user_id, 'zleadscrm_lead_archive_status', 'false' );

			$user = new WP_User( $user_id );

			$user->remove_role( 'subscriber' );

			$user->add_role( 'lead' );

			zleadscrm_insert_lead_edit_audit( array(
				'action'    => 'Lead created',
				'old_value' => '-',
				'new_value' => '-',
				'user_id'   => $user_id,
				'editor_id' => get_current_user_id()
			) );

			print( $redirect_url );
			exit();

		}


		public function edit_settings() {
			if ( ! isset( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'zleadscrm_edit_settings' ) ) {
				wp_redirect( 'admin.php?page=zleadscrm_settings' );
				exit();
			}

			if ( isset( $_POST['zleadscrm_users_allowed_access_pipelines_setting'] ) ) {
				update_option( 'zleadscrm_users_allowed_access_pipelines_setting', sanitize_text_field( $_POST['zleadscrm_users_allowed_access_pipelines_setting'] ) );
			}

			if ( isset( $_POST['zleadscrm_allowed_access_pipelines_users'] ) ) {
				update_option( 'zleadscrm_allowed_access_pipelines_users', zleadscrm_sanitize_array( $_POST['zleadscrm_allowed_access_pipelines_users'] ) );
			}

			wp_redirect( 'admin.php?page=zleadscrm_settings&_wpnonce=' . $_POST['_wpnonce'] );
			exit();

		}

		public function admin_menu() {

			if ( zleadscrm_user_can_access_pipelines( get_current_user_id() ) ) {

				add_submenu_page( 'zleadscrm_bookmarks', 'Pipeline', 'Pipeline', 'read', 'zleadscrm_pipelines', array(
					$this,
					'show_zleadscrm_pipelines'
				) );
			}

			zleadscrm_sort_zleadscrm_menu();
		}

		public function show_zleadscrm_pipelines() { // Pipeline Page
			include_once( ZLEADSCRM_PIPELINE_PLUGIN_DIR . 'template/pipeline.php' );
		}
	}

?>